@@ -1,4 +1,3 @@
-from .methods._lookups import *
 from .methods.alert import *
 from .methods.datasource import *
 from .methods.extract import *
@@ -6,6 +5,7 @@ from .methods.favorites import *
 from .methods.flow import *
 from .methods.group import *
 from .methods.metadata import *
+from .methods.metrics import *
 from .methods.project import *
 from .methods.revision import *
 from .methods.schedule import *
