@@ -15,14 +15,14 @@ from ._lookups import LookupMethods
 from tableau_tools.tableau_exceptions import *
 from tableau_tools.tableau_rest_api.rest_xml_request import RestXmlRequest
 from tableau_tools.tableau_rest_api.rest_json_request import RestJsonRequest
-from tableau_tools.tableau_rest_api.published_content import Project, Project28, Project33, Workbook, Datasource, Flow33
+from tableau_tools.tableau_rest_api.published_content import Project, Project33, Workbook, Datasource, Flow33
 from tableau_tools.tableau_rest_api.url_filter import *
 from tableau_tools.tableau_rest_api.sort import *
 from ...tableau_rest_xml import TableauRestXml
 
-class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
+class TableauRestApiBase(LoggingMethods, TableauRestXml):
     # Defines a class that represents a RESTful connection to Tableau Server. Use full URL (http:// or https://)
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.2"):
         if server.find('http') == -1:
             raise InvalidOptionException('Server URL must include http:// or https://')
 
@@ -47,7 +47,7 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
         self._request_json_obj: Optional[RestJsonRequest] = None
 
         # UrlFilter object for factory methods
-        self.url_filters = UrlFilter
+        self.url_filters = UrlFilter31
         self.sorts = Sort
 
         # Lookup caches to minimize calls
@@ -58,9 +58,9 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
         self.verify_ssl_cert = True
 
         self.version: Optional[str] = None
-        self.api_version: Optional[str]  = None
-        # Starting in version 5 of tableau_tools, 10.3 is the lowest supported version
-        self.set_tableau_server_version("10.3")
+        self.api_version: str  = api_version
+        # Starting in version 6 of tableau_tools,  2018.3 is the lowest supported version
+        self.set_tableau_server_version("2018.3")
 
         # Try to see if this gets the composition right
         self.rest_api_base = self
@@ -82,40 +82,12 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
             u'SiteAdministratorCreator'
         )
 
-
-
-    def set_tableau_server_version(self, tableau_server_version: str) -> str:
-        if str(tableau_server_version)in ["10.3", "10.4", "10.5", '2018.1', '2018.2', '2018.3', '2019.1',
-                                          '2019.2', '2019.3', '2019.4']:
-            if str(tableau_server_version) == '10.3':
-                self.api_version = '2.6'
-            elif str(tableau_server_version) == '10.4':
-                self.api_version = '2.7'
-            elif str(tableau_server_version) == '10.5':
-                self.api_version = '2.8'
-            elif str(tableau_server_version) == '2018.1':
-                self.api_version = '3.0'
-            elif str(tableau_server_version) == '2018.2':
-                self.api_version = '3.1'
-            elif str(tableau_server_version) == '2018.3':
-                self.api_version = '3.2'
-            elif str(tableau_server_version) == '2019.1':
-                self.api_version = '3.3'
-            elif str(tableau_server_version) == '2019.2':
-                self.api_version = '3.4'
-            elif str(tableau_server_version) == '2019.3':
-                self.api_version = '3.5'
-            elif str(tableau_server_version) == '2019.4':
-                self.api_version = '3.6'
-            self.tableau_namespace = 'http://tableau.com/api'
-            self.ns_map = {'t': 'http://tableau.com/api'}
-            self.version = tableau_server_version
-            self.ns_prefix = '{' + self.ns_map['t'] + '}'
-            #print("Current API Version set to: {}".format(self.api_version))
-            return self.api_version
-
-        else:
-            raise InvalidOptionException("Please specify tableau_server_version as a string. '10.5' or '2019.3' etc...")
+    # Legacy, may not be necessary
+    def set_tableau_server_version(self, tableau_server_version: str):
+        self.tableau_namespace = 'http://tableau.com/api'
+        self.ns_map = {'t': 'http://tableau.com/api'}
+        self.version = tableau_server_version
+        self.ns_prefix = '{' + self.ns_map['t'] + '}'
 
 
     # Method to handle single str or list and return a list
@@ -615,8 +587,6 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
         self.end_log_block()
         return xml
 
-
-
     def send_add_request(self, url: str, request: ET.Element) -> ET.Element:
         self.start_log_block()
         if self.token == "":
@@ -832,6 +802,7 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
                             v = ET.Element('view')
                             v.set('name', view_name)
                             v.set('hidden', 'true')
+                            vs.append(v)
                         t1.append(vs)
 
                 # Description only allowed for Flows as of 3.3
@@ -984,6 +955,7 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
                                                                                            e.tableau_error_code))
             self.end_log_block()
             raise
+
     def query_server_info(self) -> ET.Element:
         self.start_log_block()
         server_info = self.query_resource("serverinfo", server_level=True)
@@ -1066,50 +1038,227 @@ class TableauRestApiBase(LookupMethods, LoggingMethods, TableauRestXml):
         url = self.build_api_url('')[:-1]
         return self.send_publish_request(url, publish_request, None, boundary_string)
 
-class TableauRestApiBase27(TableauRestApiBase):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
-        TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
-        self.set_tableau_server_version('10.4')
-        self.url_filters = UrlFilter27
-
-class TableauRestApiBase28(TableauRestApiBase27):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
-        TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
-        self.set_tableau_server_version('10.5')
-
     def get_published_project_object(self, project_name_or_luid: str,
-                                     project_xml_obj: Optional[ET.Element] = None) -> Project28:
+                                     project_xml_obj: Optional[ET.Element] = None) -> Project:
         luid = self.query_project_luid(project_name_or_luid)
-        proj_obj = Project28(luid, self, self.version, self.logger, content_xml_obj=project_xml_obj)
+        proj_obj = Project(luid, self, self.version, self.logger, content_xml_obj=project_xml_obj)
         return proj_obj
 
-class TableauRestApiBase30(TableauRestApiBase28):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
+#
+# Lookup Methods (previously in _lookups.py)
+#
+
+    def query_user_luid(self, username: str) -> str:
+        self.start_log_block()
+        if username in self.username_luid_cache:
+            user_luid = self.username_luid_cache[username]
+        else:
+            user_luid = self.query_luid_from_name(content_type="user", name=username)
+            self.username_luid_cache[username] = user_luid
+        self.end_log_block()
+        return user_luid
+
+    # Datasources in different projects can have the same 'pretty name'.
+    def query_datasource_luid(self, datasource_name: str, project_name_or_luid: Optional[str] = None,
+                              content_url: Optional[str] = None) -> str:
+        self.start_log_block()
+        if self.is_luid(datasource_name):
+            return datasource_name
+        # This quick filters down to just those with the name
+
+        datasources_with_name = self.query_elements_from_endpoint_with_filter('datasource', datasource_name)
+
+        # Throw exception if nothing found
+        if len(datasources_with_name) == 0:
+            self.end_log_block()
+            raise NoMatchFoundException("No datasource found with name {} in any project".format(datasource_name))
+
+        # Search for ContentUrl which should be unique, return
+        if content_url is not None:
+            datasources_with_content_url = datasources_with_name.findall(
+                './/t:datasource[@contentUrl="{}"]'.format(content_url), TableauRestXml.ns_map)
+            self.end_log_block()
+            if len(datasources_with_name) == 1:
+                return datasources_with_content_url[0].get("id")
+            else:
+                raise NoMatchFoundException("No datasource found with ContentUrl {}".format(content_url))
+        # If no ContentUrl search, find any with the name
+        else:
+            # If no match, exception
+
+            # If no Project Name is specified, but only one match, return, otherwise throw MultipleMatchesException
+            if project_name_or_luid is None:
+                if len(datasources_with_name) == 1:
+                    self.end_log_block()
+                    return datasources_with_name[0].get("id")
+                # If no project is declared, and more than one match
+                else:
+                    raise MultipleMatchesFoundException(
+                        'More than one datasource found by name {} without a project specified'.format(datasource_name))
+            # If Project_name is specified was filtered above, so find the name
+            else:
+                if self.is_luid(project_name_or_luid):
+                    ds_in_proj = datasources_with_name.findall('.//t:project[@id="{}"]/..'.format(project_name_or_luid),
+                                                               TableauRestXml.ns_map)
+                else:
+                    ds_in_proj = datasources_with_name.findall(
+                        './/t:project[@name="{}"]/..'.format(project_name_or_luid),
+                        TableauRestXml.ns_map)
+                if len(ds_in_proj) == 1:
+                    self.end_log_block()
+                    return ds_in_proj[0].get("id")
+                else:
+                    self.end_log_block()
+                    raise NoMatchFoundException(
+                        "No datasource found with name {} in project {}".format(datasource_name, project_name_or_luid))
+
+    def query_group_luid(self, group_name: str) -> str:
+        self.start_log_block()
+
+        if group_name in self.group_name_luid_cache:
+            group_luid = self.group_name_luid_cache[group_name]
+            self.log('Found group name {} in cache with luid {}'.format(group_name, group_luid))
+        else:
+            group_luid = self.query_luid_from_name(content_type='group', name=group_name)
+            self.group_name_luid_cache[group_name] = group_luid
+        self.end_log_block()
+        return group_luid
+
+    def query_group_name(self, group_luid: str) -> str:
+        self.start_log_block()
+        for name, luid in list(self.group_name_luid_cache.items()):
+            if luid == group_luid:
+                group_name = name
+                self.log('Found group name {} in cache with luid {}'.format(group_name, group_luid))
+                return group_name
+        # If match is found
+        group = self.query_single_element_from_endpoint('group', group_luid)
+        group_luid = group.get("id")
+        group_name = group.get('name')
+        self.log('Loading the Group: LUID cache')
+        self.group_name_luid_cache[group_name] = group_luid
+        self.end_log_block()
+        return group_name
+
+    def query_project_luid(self, project_name: str) -> str:
+        self.start_log_block()
+        project_luid = self.query_luid_from_name(content_type='project', name=project_name)
+        self.end_log_block()
+        return project_luid
+
+    def query_schedule_luid(self, schedule_name: str) -> str:
+        self.start_log_block()
+        luid = self.query_single_element_luid_by_name_from_endpoint('schedule', schedule_name, server_level=True)
+        self.end_log_block()
+        return luid
+
+    def query_workbook_view_luid(self, wb_name_or_luid: str, view_name: Optional[str] = None,
+                                 view_content_url: Optional[str] = None, proj_name_or_luid: Optional[str] = None,
+                                 username_or_luid: Optional[str] = None, usage: bool = False)-> str:
+        self.start_log_block()
+        if usage not in [True, False]:
+            raise InvalidOptionException('Usage can only be set to True or False')
+        # Short circuit check if a LUID is passed in
+        if self.is_luid(view_name):
+            return view_name
+        wb_luid = self.query_workbook_luid(wb_name_or_luid, proj_name_or_luid)
+        vws = self.query_resource("workbooks/{}/views?includeUsageStatistics={}".format(wb_luid, str(usage).lower()))
+        if view_content_url is not None:
+            views_with_name = vws.findall('.//t:view[@contentUrl="{}"]'.format(view_content_url), TableauRestXml.ns_map)
+        else:
+            views_with_name = vws.findall('.//t:view[@name="{}"]'.format(view_name), TableauRestXml.ns_map)
+        if len(views_with_name) == 0:
+            self.end_log_block()
+            raise NoMatchFoundException('No view found with name {} or content_url {} in workbook {}'.format(view_name, view_content_url, wb_name_or_luid))
+        elif len(views_with_name) > 1:
+            self.end_log_block()
+            raise MultipleMatchesFoundException(
+                'More than one view found by name {} in workbook {}. Use view_content_url parameter'.format(view_name, view_content_url, wb_name_or_luid))
+        view_luid = views_with_name[0].get('id')
+        self.end_log_block()
+        return view_luid
+
+    def query_workbook_luid(self, wb_name: str, proj_name_or_luid: Optional[str] = None) -> str:
+        self.start_log_block()
+        # Short circuit if LUID is passed in
+        if self.is_luid(wb_name):
+            return wb_name
+        workbooks_with_name = self.query_elements_from_endpoint_with_filter('workbook', wb_name)
+        if len(workbooks_with_name) == 0:
+            self.end_log_block()
+            raise NoMatchFoundException("No workbook found for named {}".format(wb_name))
+        elif len(workbooks_with_name) == 1:
+            wb_luid = workbooks_with_name[0].get("id")
+            self.end_log_block()
+            return wb_luid
+        elif len(workbooks_with_name) > 1 and proj_name_or_luid is not None:
+            if self.is_luid(proj_name_or_luid):
+                wb_in_proj = workbooks_with_name.findall('.//t:project[@id="{}"]/..'.format(proj_name_or_luid),
+                                                           TableauRestXml.ns_map)
+            else:
+                wb_in_proj = workbooks_with_name.findall(
+                    './/t:project[@name="{}"]/..'.format(proj_name_or_luid),
+                    TableauRestXml.ns_map)
+            if len(wb_in_proj) == 0:
+                self.end_log_block()
+                raise NoMatchFoundException('No workbook found with name {} in project {}'.format(wb_name, proj_name_or_luid))
+            wb_luid = wb_in_proj[0].get("id")
+            self.end_log_block()
+            return wb_luid
+        else:
+            self.end_log_block()
+            raise MultipleMatchesFoundException('More than one workbook found by name {} without a project specified'.format(wb_name))
+
+    def query_database_luid(self, database_name: str) -> str:
+            self.start_log_block()
+            # Short circuit if LUID is passed in
+            if self.is_luid(database_name):
+                return database_name
+            databases = self.query_resource("databases")
+            databases_with_name = databases.findall('.//t:database[@name="{}"]'.format(database_name), TableauRestXml.ns_map)
+            if len(databases_with_name) == 0:
+                self.end_log_block()
+                raise NoMatchFoundException(
+                    "No database found named {}".format(database_name))
+            elif len(databases_with_name) == 1:
+                db_luid = databases_with_name[0].get("id")
+                self.end_log_block()
+                return db_luid
+            else:
+                self.end_log_block()
+                raise MultipleMatchesFoundException(
+                    'More than one database found by name {}. Please determine LUID using another method'.format(database_name))
+
+    def query_table_luid(self, table_name: str) -> str:
+            self.start_log_block()
+            # Short circuit if LUID is passed in
+            if self.is_luid(table_name):
+                return table_name
+            tables = self.query_resource("tables")
+            tables_with_name = tables.findall('.//t:table[@name="{}"]'.format(table_name), TableauRestXml.ns_map)
+            if len(tables_with_name) == 0:
+                self.end_log_block()
+                raise NoMatchFoundException(
+                    "No database found named {}".format(table_name))
+            elif len(tables_with_name) == 1:
+                t_luid = tables_with_name[0].get("id")
+                self.end_log_block()
+                return t_luid
+            else:
+                self.end_log_block()
+                raise MultipleMatchesFoundException(
+                    'More than one table found by name {}. Please determine LUID using another method'.format(table_name))
+
+    def query_webhook_luid(self, webhook_name: str) -> str:
+        self.start_log_block()
+        luid = self.query_single_element_luid_by_name_from_endpoint('webhook', webhook_name)
+        self.end_log_block()
+        return luid
+
+class TableauRestApiBase33(TableauRestApiBase):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str ="3.3"):
         TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
-        self.set_tableau_server_version('2018.1')
-
-
-
-class TableauRestApiBase31(TableauRestApiBase30):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
-        TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
-        self.set_tableau_server_version('2018.2')
-        self.url_filters = UrlFilter31
-
-class TableauRestApiBase32(TableauRestApiBase31):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
-        TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
-        self.set_tableau_server_version('2018.3')
-
-class TableauRestApiBase33(TableauRestApiBase32):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
-        TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
+                                    site_content_url=site_content_url, api_version=api_version)
         self.set_tableau_server_version('2019.1')
         self.url_filters = UrlFilter33
 
@@ -1128,9 +1277,9 @@ class TableauRestApiBase33(TableauRestApiBase32):
         return flow_obj
 
 class TableauRestApiBase34(TableauRestApiBase33):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.4"):
         TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
+                                    site_content_url=site_content_url, api_version=api_version)
         self.set_tableau_server_version('2019.2')
 
     # Generic implementation of all the CSV/PDF/PNG requests
@@ -1181,18 +1330,16 @@ class TableauRestApiBase34(TableauRestApiBase33):
 
 # NEED TO IMPLEMENT
 class TableauRestApiBase35(TableauRestApiBase34):
-    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = ""):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.5"):
         TableauRestApiBase.__init__(self, server=server, username=username, password=password,
-                                    site_content_url=site_content_url)
+                                    site_content_url=site_content_url, api_version=api_version)
         self.set_tableau_server_version('2019.3')
 
 
-
-
 class TableauRestApiBase36(TableauRestApiBase35):
     def __init__(self, server: str, username: Optional[str] = None, password: Optional[str] = None,
                  pat_name: Optional[str] = None, pat_secret: Optional[str] = None,
-                 site_content_url: Optional[str] = ""):
+                 site_content_url: Optional[str] = "", api_version: str = "3.6"):
         #TableauRestApiBase.__init__()
         if server.find('http') == -1:
             raise InvalidOptionException('Server URL must include http:// or https://')
@@ -1223,7 +1370,7 @@ class TableauRestApiBase36(TableauRestApiBase35):
         self.verify_ssl_cert = True
 
         self.version: Optional[str] = None
-        self.api_version: Optional[str]  = None
+        self.api_version: Optional[str]  = api_version
         # Starting in version 5 of tableau_tools, 10.3 is the lowest supported version
         self.set_tableau_server_version("2019.4")
 
@@ -1287,3 +1434,68 @@ class TableauRestApiBase36(TableauRestApiBase35):
         self._request_obj.url = None
         self._request_obj.xml_request = None
         self.end_log_block()
+
+class TableauRestApiBase37(TableauRestApiBase36):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.7"):
+        TableauRestApiBase36.__init__(self, server=server, username=username, password=password,
+                                    site_content_url=site_content_url, api_version=api_version)
+        self.set_tableau_server_version('2020.1')
+
+class TableauRestApiBase38(TableauRestApiBase37):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.8"):
+        TableauRestApiBase36.__init__(self, server=server, username=username, password=password,
+                                    site_content_url=site_content_url, api_version=api_version)
+        self.set_tableau_server_version('2020.2')
+
+    def get_current_server_session(self) -> ET.Element:
+        self.start_log_block()
+        sessions = self.query_resource("sessions/current", server_level=True)
+        self.end_log_block()
+        return sessions
+
+
+class TableauRestApiBase39(TableauRestApiBase38):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.9"):
+        TableauRestApiBase36.__init__(self, server=server, username=username, password=password,
+                                    site_content_url=site_content_url, api_version=api_version)
+        self.set_tableau_server_version('2020.3')
+
+    def delete_server_session(self, session_id: str):
+        self.start_log_block()
+        url = self.build_api_url("sessions/{}".format(session_id), server_level=True)
+        self.send_delete_request(url)
+        self.end_log_block()
+
+
+class TableauRestApiBase310(TableauRestApiBase39):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.9"):
+        TableauRestApiBase36.__init__(self, server=server, username=username, password=password,
+                                    site_content_url=site_content_url, api_version=api_version)
+        self.set_tableau_server_version('2020.4')
+
+
+class TableauRestApiBase311(TableauRestApiBase310):
+    def __init__(self, server: str, username: str, password: str, site_content_url: Optional[str] = "", api_version: str = "3.9"):
+        TableauRestApiBase36.__init__(self, server=server, username=username, password=password,
+                                    site_content_url=site_content_url, api_version=api_version)
+        self.set_tableau_server_version('2021.1')
+
+    def list_server_active_directory_domains(self) -> ET.Element:
+        self.start_log_block()
+        response = self.query_resource("domains/", server_level=True)
+        self.end_log_block()
+        return response
+
+    def update_server_active_directory_domain(self, domain_id: str, new_name: Optional[str] = None,
+                                              new_short_name: Optional[str] = None) -> ET.Element:
+        self.start_log_block()
+        tsr = ET.Element("tsRequest")
+        d = ET.Element("domain")
+        if new_name is not None:
+            d.set('name', new_name)
+        if new_short_name is not None:
+            d.set('shortName', new_short_name)
+        url = self.build_api_url("domains/{}".format(domain_id), server_level=True)
+        response = self.send_update_request(url=url, request=tsr)
+        self.end_log_block()
+        return response
\ No newline at end of file
