@@ -14,14 +14,14 @@ if TYPE_CHECKING:
 
 # Represents a published workbook, project or datasource
 class PublishedContent(LoggingMethods):
-    def __init__(self, luid: str, obj_type: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
+    def __init__(self, luid: str, obj_type: str, tableau_rest_api_obj: 'TableauServerRest',
                  default: bool = False, logger_obj: Optional['Logger'] = None,
                  content_xml_obj: Optional[ET.Element] = None):
 
         self.permissionable_objects = ('datasource', 'project', 'workbook', 'flow', 'database', 'table')
         self.logger = logger_obj
         self._luid = luid
-        self.t_rest_api: Union[TableauRestApiConnection, TableauServerRest] = tableau_rest_api_obj
+        self.t_rest_api: TableauServerRest = tableau_rest_api_obj
         self.obj_type = obj_type
         self.default = default
         self.obj_perms_xml = None
@@ -114,14 +114,6 @@ class PublishedContent(LoggingMethods):
         else:
             raise InvalidOptionException('Must pass one of group_name_or_luid or username_or_luid')
 
-    # Legacy for compatibility
-    def copy_permissions_obj_for_group(self, perms_obj, group_name_or_luid):
-        return self._copy_permissions_obj(perms_obj, 'group', group_name_or_luid)
-
-    def copy_permissions_obj_for_user(self, perms_obj, username_or_luid):
-        return self._copy_permissions_obj(perms_obj, 'user', username_or_luid)
-
-
 
     # Runs through the gcap object list, and tries to do a conversion all principals to matching LUIDs on current site
     # Use case is replicating settings from one site to another
@@ -129,11 +121,6 @@ class PublishedContent(LoggingMethods):
     # Not Finished
     def convert_permissions_obj_list_from_orig_site_to_current_site(self, permissions_obj_list: List['Permissions'],
                                                                     orig_site: Union['TableauRestApiConnection', 'TableauServerRest']) -> List['Permissions']:
-        """
-        :type permissions_obj_list: list[Permissions]
-        :type orig_site: TableauRestApiConnection
-        :rtype: list[Permissions]
-        """
         # If the site is the same, skip the whole thing and just return the original
         if self.t_rest_api.site_content_url == orig_site.site_content_url \
                 and self.t_rest_api.server == orig_site.server:
@@ -594,19 +581,6 @@ class Workbook(PublishedContent):
            # self.end_log_block()
             return obj_list
 
-class Workbook28(Workbook):
-    def __init__(self, luid, tableau_rest_api_obj, default=False, logger_obj=None,
-                 content_xml_obj=None):
-        Workbook.__init__(self, luid=luid, tableau_rest_api_obj=tableau_rest_api_obj,
-                                  default=default, logger_obj=logger_obj, content_xml_obj=content_xml_obj)
-        self.__available_capabilities = Permissions.available_capabilities[self.api_version]["workbook"]
-        self.log("Workbook object initiating")
-        self.permissions_object_class = WorkbookPermissions28
-
-    def get_permissions_obj(self, group_name_or_luid: Optional[str] = None, username_or_luid: Optional[str] = None,
-                               role: Optional[str] = None) -> WorkbookPermissions28:
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, username_or_luid=username_or_luid,
-                                            role=role)
 
 class Datasource(PublishedContent):
     def __init__(self, luid, tableau_rest_api_obj,  default=False, logger_obj=None,
@@ -659,19 +633,6 @@ class Datasource(PublishedContent):
             # self.end_log_block()
             return obj_list
 
-class Datasource28(Datasource):
-    def __init__(self, luid: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
-                 default: bool = False, logger_obj: Optional['Logger'] = None,
-                 content_xml_obj: Optional[ET.Element] = None):
-        Datasource.__init__(self, luid=luid, tableau_rest_api_obj=tableau_rest_api_obj,
-                                  default=default, logger_obj=logger_obj, content_xml_obj=content_xml_obj)
-        self.__available_capabilities = Permissions.available_capabilities[self.api_version]["datasource"]
-        self.permissions_object_class = DatasourcePermissions28
-
-    def get_permissions_obj(self, group_name_or_luid: Optional[str] = None, username_or_luid: Optional[str] = None,
-                               role: Optional[str] = None) -> 'DatasourcePermissions28':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, username_or_luid=username_or_luid,
-                                            role=role)
 
 class View(PublishedContent):
     def __init__(self, luid: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
@@ -766,10 +727,13 @@ class Table35(PublishedContent):
 
 
 class Project(PublishedContent):
-    def __init__(self, luid: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
-                 logger_obj: Optional['Logger'] = None, content_xml_obj: Optional[ET.Element] = None):
+    def __init__(self, luid: str, tableau_rest_api_obj: 'TableauServerRest',
+                 logger_obj: Optional['Logger'] = None,
+                 content_xml_obj: Optional[ET.Element] = None, parent_project_luid: Optional[str] = None):
         PublishedContent.__init__(self, luid=luid, obj_type="project", tableau_rest_api_obj=tableau_rest_api_obj,
                                   logger_obj=logger_obj, content_xml_obj=content_xml_obj)
+
+        self._parent_project_luid = parent_project_luid
         self.log('Building Project object from this XML: ')
         self.log_xml_response(content_xml_obj)
         self.log('Project object has this XML: ')
@@ -900,37 +864,6 @@ class Project(PublishedContent):
 
         self.end_log_block()
 
-    # There are all legacy for compatibility purposes
-    def create_project_permissions_object_for_group(self, group_name_or_luid: str,
-                                                    role: Optional[str] = None) -> 'ProjectPermissions':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=ProjectPermissions)
-
-    def create_project_permissions_object_for_user(self, username_or_luid: str,
-                                                    role: Optional[str] = None) -> 'ProjectPermissions':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=ProjectPermissions)
-
-    def create_workbook_permissions_object_for_group(self, group_name_or_luid: str,
-                                                    role: Optional[str] = None) -> 'WorkbookPermissions':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=WorkbookPermissions)
-
-    def create_workbook_permissions_object_for_user(self, username_or_luid: str,
-                                                    role: Optional[str] = None) -> 'WorkbookPermissions':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=WorkbookPermissions)
-
-    def create_datasource_permissions_object_for_group(self, group_name_or_luid: str,
-                                                    role: Optional[str] = None) -> 'DatasourcePermissions':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=DatasourcePermissions)
-
-    def create_datasource_permissions_object_for_user(self, username_or_luid: str,
-                                                    role: Optional[str] = None) -> 'DatasourcePermissions':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=DatasourcePermissions)
-
     @property
     def workbook_defaults(self) -> Workbook:
         return self._workbook_defaults
@@ -1044,20 +977,6 @@ class Project(PublishedContent):
                 final_list.append(all_permissions["datasource_default_caps"][cap])
         return final_list
 
-
-class Project28(Project):
-    def __init__(self, luid: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
-                 logger_obj: Optional['Logger'] = None,
-                 content_xml_obj: Optional[ET.Element] = None, parent_project_luid: Optional[str] = None):
-        Project.__init__(self, luid=luid, tableau_rest_api_obj=tableau_rest_api_obj, logger_obj=logger_obj,
-                         content_xml_obj=content_xml_obj)
-        self._parent_project_luid = parent_project_luid
-        self.permissions_object_class = ProjectPermissions28
-
-    def get_permissions_obj(self, group_name_or_luid: Optional[str] = None, username_or_luid: Optional[str] = None,
-                               role: Optional[str] = None) -> 'ProjectPermissions28':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, username_or_luid=username_or_luid,
-                                            role=role)
     @property
     def parent_project_luid(self) -> str:
         return self._parent_project_luid
@@ -1074,100 +993,12 @@ class Project28(Project):
         self.end_log_block()
         return child_projects
 
-    def lock_permissions(self) -> 'Project28':
-        self.start_log_block()
-        if self.permissions_locked is False:
-            # This allows type checking without importing the class
-            if(type(self.t_rest_api).__name__.find('TableauRestApiConnection') != -1):
-                new_proj_obj = self.t_rest_api.update_project(self.luid, locked_permissions=True)
-            else:
-                new_proj_obj = self.t_rest_api.projects.update_project(self.luid, locked_permissions=True)
-            self.end_log_block()
-            return new_proj_obj
-        else:
-            self.end_log_block()
-            return self
 
-    def unlock_permissions(self) -> 'Project28':
-        self.start_log_block()
-        if self.permissions_locked is True:
-            # This allows type checking without importing the class
-            if(type(self.t_rest_api).__name__.find('TableauRestApiConnection') != -1):
-                new_proj_obj = self.t_rest_api.update_project(self.luid, locked_permissions=False)
-            else:
-                new_proj_obj = self.t_rest_api.projects.update_project(self.luid, locked_permissions=False)
-            self.end_log_block()
-            return new_proj_obj
-        else:
-            self.end_log_block()
-            return self
-
-    @staticmethod
-    def convert_capabilities_xml_into_obj_list(xml_obj: ET.Element) -> List['ProjectPermissions']:
-        # self.start_log_block()
-        obj_list = []
-        xml = xml_obj.findall('.//t:granteeCapabilities', TableauRestXml.ns_map)
-        if len(xml) == 0:
-            # self.end_log_block()
-            return []
-        else:
-            for gcaps in xml:
-                for tags in gcaps:
-                    # Namespace fun
-                    if tags.tag == '{}group'.format(TableauRestXml.ns_prefix):
-                        luid = tags.get('id')
-                        perms_obj = ProjectPermissions28('group', luid)
-                        # self.log_debug('group {}'.format(luid))
-                    elif tags.tag == '{}user'.format(TableauRestXml.ns_prefix):
-                        luid = tags.get('id')
-                        perms_obj = ProjectPermissions28('user', luid)
-                        # self.log_debug('user {}'.format(luid))
-                    elif tags.tag == '{}capabilities'.format(TableauRestXml.ns_prefix):
-                        for caps in tags:
-                            # self.log_debug(caps.get('name') + ' : ' + caps.get('mode'))
-                            perms_obj._set_capability_from_published_content(caps.get('name'), caps.get('mode'))
-                obj_list.append(perms_obj)
-            # self.log('Permissions object list has {} items'.format(str(len(obj_list))))
-            # self.end_log_block()
-            return obj_list
-
-    # There are all legacy for compatibility purposes
-    def create_project_permissions_object_for_group(self, group_name_or_luid: str,
-                                                    role: Optional[str] = None) -> 'ProjectPermissions28':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=ProjectPermissions28)
-
-    def create_project_permissions_object_for_user(self, username_or_luid: str,
-                                                   role: Optional[str] = None) -> 'ProjectPermissions28':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=ProjectPermissions28)
-
-    def create_workbook_permissions_object_for_group(self, group_name_or_luid: str,
-                                                     role: Optional[str] = None) -> 'WorkbookPermissions28':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=WorkbookPermissions28)
-
-    def create_workbook_permissions_object_for_user(self, username_or_luid: str,
-                                                    role: Optional[str] = None) -> 'WorkbookPermissions28':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=WorkbookPermissions28)
-
-    def create_datasource_permissions_object_for_group(self, group_name_or_luid: str,
-                                                       role: Optional[str] = None) -> 'DatasourcePermissions28':
-        return self._get_permissions_object(group_name_or_luid=group_name_or_luid, role=role,
-                                            permissions_class_override=DatasourcePermissions28)
-
-    def create_datasource_permissions_object_for_user(self, username_or_luid: str,
-                                                      role: Optional[str] = None) -> 'DatasourcePermissions28':
-        return self._get_permissions_object(username_or_luid=username_or_luid, role=role,
-                                            permissions_class_override=DatasourcePermissions28)
-
-
-class Project33(Project28):
+class Project33(Project):
     def __init__(self, luid: str, tableau_rest_api_obj: Union['TableauRestApiConnection', 'TableauServerRest'],
                  logger_obj: Optional['Logger'] = None, content_xml_obj: Optional[ET.Element] = None,
                  parent_project_luid:str = None):
-        Project28.__init__(self, luid=luid, tableau_rest_api_obj=tableau_rest_api_obj, logger_obj=logger_obj,
+        Project.__init__(self, luid=luid, tableau_rest_api_obj=tableau_rest_api_obj, logger_obj=logger_obj,
                            content_xml_obj=content_xml_obj, parent_project_luid=parent_project_luid)
         self.flow_defaults = Flow33(self.luid, self.t_rest_api, default=True, logger_obj=logger_obj)
 
@@ -1200,7 +1031,7 @@ class Project33(Project28):
             return self
 
     def get_permissions_obj(self, group_name_or_luid: Optional[str] = None, username_or_luid: Optional[str] = None,
-                               role: Optional[str] = None) -> 'ProjectPermissions28':
+                               role: Optional[str] = None) -> 'ProjectPermissions':
         return self._get_permissions_object(group_name_or_luid=group_name_or_luid, username_or_luid=username_or_luid,
                                             role=role)
 
